@@ -2,12 +2,13 @@ from typing import Callable
 import traceback
 from .element import Element
 from .custom_view import CustomView
+from .page import Page
 from .scene_object3d import Object3D
 
 class SceneView(CustomView):
 
     def __init__(self, *, width: int, height: int, on_click: Callable):
-        dependencies = ['three.min.js', 'OrbitControls.js']
+        dependencies = ['three.min.js', 'OrbitControls.js', 'STLLoader.js']
         super().__init__('scene', __file__, dependencies, width=width, height=height)
         self.on_click = on_click
         self.allowed_events = ['onConnect', 'onClick']
@@ -38,6 +39,7 @@ class Scene(Element):
     from .scene_objects import Sphere as sphere
     from .scene_objects import Cylinder as cylinder
     from .scene_objects import Extrusion as extrusion
+    from .scene_objects import Stl as stl
     from .scene_objects import Line as line
     from .scene_objects import Curve as curve
     from .scene_objects import Texture as texture
@@ -58,7 +60,7 @@ class Scene(Element):
 
     def __enter__(self):
         self.view_stack.append(self.view)
-        scene = self.view.objects.get('scene', SceneObject(self.view))
+        scene = self.view.objects.get('scene', SceneObject(self.view, self.page))
         Object3D.stack.clear()
         Object3D.stack.append(scene)
         return self
@@ -68,6 +70,7 @@ class Scene(Element):
 
 class SceneObject:
 
-    def __init__(self, view: SceneView):
+    def __init__(self, view: SceneView, page: Page):
         self.id = 'scene'
         self.view = view
+        self.page = page
