@@ -1,3 +1,4 @@
+from typing import Optional
 from .scene_object3d import Object3D
 
 class Scene(Object3D):
@@ -51,6 +52,14 @@ class Extrusion(Object3D):
                  ):
         super().__init__('extrusion', outline, height, wireframe)
 
+class Stl(Object3D):
+
+    def __init__(self,
+                 url: str,
+                 wireframe: bool = False,
+                 ):
+        super().__init__('stl', url, wireframe)
+
 class Line(Object3D):
 
     def __init__(self,
@@ -74,6 +83,6 @@ class Texture(Object3D):
 
     def __init__(self,
                  url: str,
-                 coordinates: list[list[tuple[float, float, float]]],
+                 coordinates: list[list[Optional[tuple[float]]]],
                  ):
         super().__init__('texture', url, coordinates)
