@@ -2,7 +2,6 @@ import inspect
 import sys
 import webbrowser
 import uvicorn
-from .elements.element import Element
 from .config import config  # NOTE: before justpy
 import justpy as jp
 
@@ -18,6 +17,4 @@ def run(self, *, host='0.0.0.0', port=80, title='NiceGUI', favicon='favicon.ico'
     if config.interactive or reload == False:  # NOTE: if reload == True we already started uvicorn above
         if show:
             webbrowser.open(f'http://{host if host != "0.0.0.0" else "127.0.0.1"}:{port}/')
-        Element.wp.title = title
-        Element.wp.favicon = favicon
         uvicorn.run(jp.app, host=host, port=port, lifespan='on')
