@@ -18,6 +18,7 @@ class Ui:
     from .elements.menu import Menu as menu
     from .elements.notify import Notify as notify
     from .elements.number import Number as number
+    from .elements.page import Page as page
     from .elements.radio import Radio as radio
     from .elements.scene import Scene as scene
     from .elements.select import Select as select
@@ -37,3 +38,10 @@ class Ui:
     from .timer import Timer as timer
 
     from .lifecycle import startup_tasks, on_startup, shutdown_tasks, on_shutdown
+
+    def __init__(self, app) -> None:
+        self.app = app
+        
+
+    def add_route(self, route):
+        self.app.routes.insert(0, route)
\ No newline at end of file
